@@ -5,7 +5,7 @@
 ## To get the version number of the available libgmail version.
 ## Reminder: add date before next release. This attribute is also
 ## used in the setup script.
-Version = '0.1.10' # (July 2008)
+Version = '0.1.11' # (August 2008)
 
 # Original author: follower@rancidbacon.com
 # Maintainers: Waseem (wdaher@mit.edu) and Stas Z (stas@linux.isbeter.nl)
@@ -355,8 +355,7 @@ class GmailAccount:
         self._cookieJar.extract_cookies(resp, req)
 
         # TODO: Enable logging of page data for debugging purposes?
-        return pageData.decode('utf-8')
-
+        return pageData
 
     def _parsePage(self, urlOrRequest):
         """
@@ -1406,7 +1405,6 @@ class GmailThread(_LabelHandlerMixin):
                 for msg in msgsInfo:
                     result += [GmailMessage(thread, msg, isDraft = isDraft)]
                            
-
         return result
 
 class GmailMessageStub(_LabelHandlerMixin):
@@ -1443,17 +1441,24 @@ class GmailMessage(object):
         self._parent = parent
         self._account = self._parent._account
         
-        self.author = msgData[MI_AUTHORFIRSTNAME]
+        self.author = msgData[MI_AUTHORFIRSTNAME].decode('utf-8')
+        self.author_fullname = msgData[MI_AUTHORNAME].decode('utf-8')
         self.id = msgData[MI_MSGID]
         self.number = msgData[MI_NUM]
-        self.subject = msgData[MI_SUBJECT]
-        self.to = msgData[MI_TO]
-        self.cc = msgData[MI_CC]
-        self.bcc = msgData[MI_BCC]
-        self.sender = msgData[MI_AUTHOREMAIL]
+        self.subject = msgData[MI_SUBJECT].decode('utf-8')
+        self.to = [x.decode('utf-8') for x in msgData[MI_TO]]
+        self.cc = [x.decode('utf-8') for x in msgData[MI_CC]]
+        self.bcc = [x.decode('utf-8') for x in msgData[MI_BCC]]
+        self.sender = msgData[MI_AUTHOREMAIL].decode('utf-8')
         
-        self.attachments = [GmailAttachment(self, attachmentInfo)
-                            for attachmentInfo in msgData[MI_ATTACHINFO]]
+        # Messages created by google chat (from reply with chat, etc.)
+        # don't have any attachments, so we need this check not to choke
+        # on them
+        try:
+            self.attachments = [GmailAttachment(self, attachmentInfo)
+                    for attachmentInfo in msgData[MI_ATTACHINFO]]
+        except TypeError:
+            self.attachments = []
 
         # TODO: Populate additional fields & cache...(?)
 
@@ -1472,7 +1477,7 @@ class GmailMessage(object):
             #       to make it legal as per RFC?
             self._source = self._account.getRawMessage(self.id)
 
-        return self._source
+        return self._source.decode('utf-8')
 
     source = property(_getSource, doc = "")
         
